@@ -6,7 +6,7 @@ from logging import INFO, Logger, getLogger
 from multiprocessing import Process, Queue
 from queue import Empty
 from signal import SIGUSR1, SIGUSR2, signal
-from typing import Any, Iterable, Iterator, Sequence, Type
+from typing import Any, Iterator, Sequence, Type
 
 from setproctitle import setproctitle
 
@@ -85,9 +85,9 @@ class BaseWorker:
             result['result'] = self.run(system, args)
         except SSHConnectionError:
             syslogger(system).error('Could not establish SSH connection.')
-            result['success'] = False
+            result['online'] = False
         else:
-            result['success'] = True
+            result['online'] = True
 
         result['end'] = (end := datetime.now()).isoformat()
         result['duration'] = str(end - start)
@@ -107,16 +107,13 @@ def multiprocess(
 ) -> dict:
     """Spawns workers and waits for them to finish."""
 
-    results = Queue()
-    wait_for_processes(
-        spawn_workers(
-            worker_cls,
-            processes,
-            sequence_to_queue(systems),
-            results,
-            args
-        )
-    )
+    wait_for_processes(list(spawn_workers(
+        worker_cls,
+        processes,
+        sequence_to_queue(systems),
+        results := Queue(),
+        args
+    )))
     return dict(iter_queue(results))
 
 
@@ -147,11 +144,9 @@ def spawn_workers(
         yield process
 
 
-def wait_for_processes(processes: Iterable[Process]) -> None:
+def wait_for_processes(processes: list[Process]) -> None:
     """Wait for the given processes."""
 
-    processes = list(processes)
-
     try:
         for process in processes:
             process.join()
@@ -159,9 +154,11 @@ def wait_for_processes(processes: Iterable[Process]) -> None:
         for process in processes:
             process.kill()
 
+        raise
+
 
 def iter_queue(queue: Queue) -> Iterator[Any]:
-    """Returns queue elements as dict."""
+    """Yield queue items."""
 
     while not queue.empty():
-        yield queue.get_nowait()
+        yield queue.get()
